==> haskell-authenticate-1.3.3.1-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-authenticate/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3.1
id: authenticate-1.3.3.1-d5d29d33a55e5a55915307e270a92892
key: authe_Dxn7PksFyDK8GfnJ1Eeg65
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3.1
hs-libraries: HSauthenticate-1.3.3.1-Dxn7PksFyDK8GfnJ1Eeg65
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    http-conduit-2.1.10.1-25cf7e0ab425a3f9a6e4adec2d684722
    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    tagstream-conduit-0.5.5.3-f8e008e7194de2867448b23ac901f0b1
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    xml-conduit-1.3.4.2-dfa752a9941da549533f5136393fb800
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.3.1-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-authenticate/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3.1
id: authenticate-1.3.3.1-8e74591c5ee8d164fe0e2c4ea7f09e6c
key: authe_Eolxs8WWZdL5HmE7MQHxvb
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3.1
hs-libraries: HSauthenticate-1.3.3.1-Eolxs8WWZdL5HmE7MQHxvb
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    http-conduit-2.1.10.1-9bcd28b714a9db44a394bc84b9d644e0
    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    network-uri-2.6.1.0-522aa8cc2805dab5af7064f70c4a777d
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    tagstream-conduit-0.5.5.3-034cc2b60823e9366fbb547594b8242d
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    xml-conduit-1.3.5-b0d7925ea0f1a62fe18b3cdd25dd3416
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
